@@ -18,7 +18,16 @@ fipscounty <- function(county = NULL, code = NULL, url = eurl(), ...){
   args <- rc(list(county = county, code = code))
   cli <- crul::HttpClient$new(url = file.path(pu(url), 'convert/fipscounty.txt'), 
     opts = list(...))
-  res <- cli$get(query = args)
+  # res <- cli$get(query = args)
+  response <- tryCatch(
+    {
+      res <- cli$get(query = args)  # Attempt to fetch
+    },
+    error = function(e) {
+      message("Curl request failed to get FIPS country code: ", e$message)
+      quit(save = "no", status = 1)  # Gracefully exit R session
+    }
+  )
   res$raise_for_status()
   res$parse("UTF-8")
 }
